#include "float2ascii.h"
// Lcd module connections
sbit LCD_RS at RB4_bit;
sbit LCD_EN at RB5_bit;
sbit LCD_D4 at RB0_bit;
sbit LCD_D5 at RB1_bit;
sbit LCD_D6 at RB2_bit;
sbit LCD_D7 at RB3_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;

#define CALIBRATED_0G_Z 368 //this is the analog value for the zero G point for Z
#define CALIBRATED_0G_X 348   //this is the analog value for the zero G point for X
#define CALIBRATED_SENSITIVITY 19//this number will convert 10bit analog values
                                 //into Gs
char * txtX;
char * txtZ;
char XAxis[30];
char ZAxis[30];
signed int oldXanalogvalue=0;
signed int oldZanalogvalue=0;

void MyDelay(int time)
{
 switch (time)
 {
 case 10 : delay_us(10);
 case 100 : delay_ms(100);
 }
}

float ReadXAxis (void)
{
     signed int analogvalue=0;
     signed int temp=0;
     signed int Gvalue=0;
     float GvalueFloat=0;
     ADCON0 = 0b11001101;     // setting the A/D module for AN1
     analogvalue = ADC_Read(1);
      MyDelay(10);
      analogvalue += ADC_Read(1);//take an average of 2 readings to reduce noise
      while (ADCON0.B2);
      analogvalue = analogvalue / 2;
      temp = analogvalue-oldXanalogvalue;
      
      if( temp>1 || temp<-1 ) //ignore small changes to make display more readable
      {
         //convert analog value into G digits
         oldXanalogvalue=analogvalue;
         Gvalue=analogvalue-CALIBRATED_0G_X;
         Gvalue=Gvalue<<5;                     //left shifting then dividing allows you to perform
         Gvalue=Gvalue/CALIBRATED_SENSITIVITY; //more precise multiplication/division
         GvalueFloat = Gvalue;
         GvalueFloat = GvalueFloat /100;
         return GvalueFloat;
      }
      return 1;
}

float ReadZAxis (void)
{
     signed int analogvalue=0;
     signed int temp=0;
     signed int Gvalue=0;
     float GvalueFloat=0;
     ADCON0 = 0b11010101;     // setting the A/D module for AN2
     analogvalue = ADC_Read(2);
     MyDelay(10);
     analogvalue += ADC_Read(2);//take an average of 2 readings to reduce noise
     while (ADCON0.B2);
     analogvalue = analogvalue / 2;
     temp = analogvalue-oldZanalogvalue;

      if( temp>1 || temp<-1 ) //ignore small changes to make display more readable
      {
         //convert analog value into G digits
         oldZanalogvalue=analogvalue;
         Gvalue=analogvalue-CALIBRATED_0G_Z;
         Gvalue=Gvalue<<5;                     //left shifting then dividing allows you to perform
         Gvalue=Gvalue/CALIBRATED_SENSITIVITY; //more precise multiplication/division
         GvalueFloat = Gvalue;
         GvalueFloat = GvalueFloat /100;
         return GvalueFloat;
      }
     return 1;
}


void main(){
     float XValues = 0;
     float ZValues = 0;
     float temp=0;
     OSCCON = 0b01110100;  // Set internal oscillator to 8mhz
     ADCON0 = 0b11010000;     // setting the A/D module for AN2
     ADCON1 = 0b11000000;        // Set all AN ports to Analog
     TRISA  = 0b00000110;     //Set RA2 & RA1 as input, others are output
     TRISB  = 0b00000000;     // Set all RB as output
     Lcd_Init();                        // Initialize Lcd
     
  while(1) {                         // Endless loop
         temp = ReadXAxis();
         if (temp != 1) XValues = temp;
         temp = ReadZAxis();
         if (temp != 1) ZValues = temp;
         Float2Ascii(XValues,txtX,2);
         txtX = XAxis;
         Float2Ascii(ZValues,txtZ,2);
         txtZ = ZAxis;
         Lcd_Cmd(_LCD_CLEAR);
         Lcd_Cmd(_LCD_CURSOR_OFF);
         Lcd_Out(1,1,"Z=");
         Lcd_Out_Cp(Ltrim(txtZ));
         Lcd_Out_Cp("G");
         Lcd_Out(2,1,"X=");
         Lcd_Out_Cp(Ltrim(txtX));
         Lcd_Out_Cp("G");
         MyDelay(100);
      }
 }